Stan Math Library: stan/math/prim/mat/fun/make_nu.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
make_nu.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/meta/index_type.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
const Eigen::Array< T, Eigen::Dynamic, 1 > | stan::math::make_nu (const T eta, const size_t K)
| This function calculates the degrees of freedom for the t distribution that corresponds to the shape parameter in the Lewandowski et. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.